@@ -19,13 +19,13 @@
 #ifndef KLIBLOADERTEST5_MODULE_H
 #define KLIBLOADERTEST5_MODULE_H
 
-#include <QtCore/QObject>
+#include <QObject>
 class KLibLoaderTestObject : public QObject
 {
     Q_OBJECT
 public:
     KLibLoaderTestObject(QObject *parent, const QList<QVariant> &);
-    ~KLibLoaderTestObject();
+    ~KLibLoaderTestObject() override;
 };
 
 #endif //KLIBLOADERTEST5_MODULE_H
