@@ -24,7 +24,6 @@
 #include <config-date.h> // SIZEOF_TIME_T
 
 #if HAVE_SYS_TIME_H
-#include <sys/time.h>
 #endif
 #if HAVE_TIME_H
 #include <time.h>
@@ -1215,7 +1214,7 @@ QList<int> KTimeZoneData::utcOffsets() const
         if (d->utcOffsets.isEmpty()) {
             d->utcOffsets += 0;
         } else {
-            qSort(d->utcOffsets);
+            std::sort(d->utcOffsets.begin(), d->utcOffsets.end());
         }
     }
     return d->utcOffsets;
