@@ -27,9 +27,9 @@
 #warning "This file is deprecated."
 #endif
 
-#include <QtCore/QVariant>
-#include <QtCore/QUrl>
-#include <QtCore/QMap>
+#include <QVariant>
+#include <QUrl>
+#include <QMap>
 
 class QStringList;
 class QMimeData;
@@ -316,7 +316,7 @@ public:
 #ifndef KDELIBS4SUPPORT_NO_DEPRECATED
         KDELIBS4SUPPORT_DEPRECATED static KUrl::List fromMimeData(const QMimeData *mimeData,
                 DecodeOptions decodeOptions = PreferKdeUrls,
-                KUrl::MetaDataMap *metaData = 0);
+                KUrl::MetaDataMap *metaData = nullptr);
 #endif
     };
     /**
@@ -346,7 +346,7 @@ public:
      * @deprecated since 5.0, use QUrl(str) if it's a URL, QUrl::fromLocalFile(str) if it's a local path,
      * and QUrl::fromUserInput() if it could be either.
      */
-    explicit KUrl(const char *urlOrPath);
+    KDELIBS4SUPPORT_DEPRECATED explicit KUrl(const char *urlOrPath);
     /**
      * Constructor taking a QByteArray @p urlOrPath, which is an _encoded_ representation
      * of the URL, exactly like the usual constructor. This is useful when
@@ -356,7 +356,7 @@ public:
      * @deprecated since 5.0, use QUrl(str) if it's a URL, QUrl::fromLocalFile(str) if it's a local path,
      * and QUrl::fromUserInput() if it could be either.
      */
-    explicit KUrl(const QByteArray &urlOrPath);
+    KDELIBS4SUPPORT_DEPRECATED explicit KUrl(const QByteArray &urlOrPath);
 
     /**
      * Copy constructor.
@@ -434,8 +434,10 @@ public:
      * @return The current decoded path. This does not include the query. Can
      *         be QString() if no path is set.
      *
-     * @deprecated since 5.0, use QUrl::path(). If RemoveTrailingSlash was used, use
-     * url.adjusted(QUrl::StripTrailingSlash).path()
+     * @deprecated since 5.0, use OUrl::toLocalFile() for local file urls and
+     * QUrl::path() for all other cases. You may use QUrl::isLocalFile() to decide
+     * which method to choose. If RemoveTrailingSlash was used, use
+     * url.adjusted(QUrl::StripTrailingSlash).path().
      */
     QString path(AdjustPathOption trailing = LeaveTrailingSlash) const;
 
@@ -707,7 +709,7 @@ public:
      * query items.
      * @deprecated since 5.0, use QUrlQuery(url).queryItems()
      */
-    QMap< QString, QString > queryItems(const QueryItemsOptions &options = 0) const;
+    QMap< QString, QString > queryItems(const QueryItemsOptions &options = {}) const;
 
     /**
      * Returns the value of a certain query item.
@@ -730,7 +732,7 @@ public:
      *
      * @param _item Name of item to add
      * @param _value Value of item to add
-     * @deprecated since 5.0, use QUrlQuery(url), then addQueryItems(), then QUrl::setQuery()
+     * @deprecated since 5.0, use QUrlQuery(url), then addQueryItem(), then QUrl::setQuery()
      */
     void addQueryItem(const QString &_item, const QString &_value);
 
@@ -993,7 +995,7 @@ public:
      * equals(u, KUrl::CompareWithoutTrailingSlash|KUrl::AllowEmptyPath) needs manual handling
      * (it was mostly unused).
      */
-    bool equals(const KUrl &u, const EqualsOptions &options = 0) const;
+    bool equals(const KUrl &u, const EqualsOptions &options = {}) const;
 
     /**
      * Checks whether the given URL is parent of this URL.
@@ -1147,7 +1149,7 @@ public:
      * @deprecated since 5.0, use QDir(base_dir).relativeFilePath(path). isParent can be
      * replaced with a call to startsWith("..") on the result value.
      */
-    static QString relativePath(const QString &base_dir, const QString &path, bool *isParent = 0);
+    static QString relativePath(const QString &base_dir, const QString &path, bool *isParent = nullptr);
 
 private:
     void _setQuery(const QString &query);
